"""Basic Details of package
"""
from os.path import join

__title__ = 'jirakosaar'
__description__ = 'Command line tool to get summary of jira issues.'
__url__ = 'https://github.com/diwap/jirakosaar'
__version__ = '1.0.4'
__author__ = 'Diwakar Pandey'
__author_email__ = 'dexterisdiwap@gmail.com'
__license__ = 'GPL-30.0 License'
__copyright__ = 'Copyright 2020 Diwakar Pandey'
__scripts__ = [join("bin", "jirakosaar")]
